# Rhasspy ASR

[![Continous Integration](https://github.com/rhasspy/rhasspy-asr/workflows/Tests/badge.svg)](https://github.com/rhasspy/rhasspy-asr/actions)
[![PyPI package version](https://img.shields.io/pypi/v/rhasspy-asr.svg)](https://pypi.org/project/rhasspy-asr)
[![Python versions](https://img.shields.io/pypi/pyversions/rhasspy-asr.svg)](https://www.python.org)
[![GitHub license](https://img.shields.io/github/license/rhasspy/rhasspy-asr.svg)](https://github.com/rhasspy/rhasspy-asr/blob/master/LICENSE)

Classes for automated speech recognition in [Rhasspy](https://github.com/synesthesiam/rhasspy) voice assistant.
